<?php

ini_set("display_errors", "on");

require_once dirname(__DIR__) . '/api_sdk/vendor/autoload.php';

use Aliyun\Core\Config;
use Aliyun\Core\Exception\ClientException;
use Aliyun\Core\Profile\DefaultProfile;
use Aliyun\Core\DefaultAcsClient;
use Aliyun\Api\Dycdp\Request\V20170525\ChargeRequest;
use Aliyun\Api\Dycdp\Request\V20170525\QueryChargeDetailRequest;
use Aliyun\Api\Dycdp\Request\V20170525\QueryGradesRequest;
use Aliyun\Api\Dycdp\Request\V20170525\ChargeByOfferRequest;

// 加载区域结点配置
Config::load();

/**
 * Class CdpDemo
 *
 * 流量服务API产品的DEMO程序，直接执行此文件即可体验流量服务产品API功能
 * (只需要将AK替换成开通了云通信-流量服务产品功能的AK即可)
 * 备注:Demo工程编码采用UTF-8
 */
class CdpDemo
{

    static $acsClient = null;

    /**
     * 取得AcsClient
     *
     * @return DefaultAcsClient
     */
    public static function getAcsClient() {
        //产品名称:云通信流量服务API产品,开发者无需替换
        $product = "Dycdpapi";

        //产品域名,开发者无需替换
        $domain = "dycdpapi.aliyuncs.com";

        // TODO 此处需要替换成开发者自己的AK (https://ak-console.aliyun.com/)
        $accessKeyId = "yourAccessKeyId"; // AccessKeyId

        $accessKeySecret = "yourAccessKeySecret"; // AccessKeySecret


        // 暂时不支持多Region
        $region = "cn-hangzhou";

        // 服务结点
        $endPointName = "cn-hangzhou";


        if(static::$acsClient == null) {

            //初始化acsClient,暂不支持region化
            $profile = DefaultProfile::getProfile($region, $accessKeyId, $accessKeySecret);

            // 增加服务结点
            DefaultProfile::addEndpoint($endPointName, $region, $product, $domain);

            // 初始化AcsClient用于发起请求
            static::$acsClient = new DefaultAcsClient($profile);
        }
        return static::$acsClient;
    }

    /**
     * 流量发放
     *
     * @return stdClass
     * @throws ClientException
     */
    public static function charge() {

        $request = new ChargeRequest();

        //可选-启用https协议
        //$request->setProtocol("https");

        //必填-需要充值的手机号
        $request->setPhoneNumber("13000000000");
        //必填-充值档位，可通过档位查询接口查询支持的档位
        $request->setGrade("50");
        //选填-是否分省，默认是false
        $request->setIsProvince(false);
        //选填-充值原因
        $request->setReason("活动充值送流量");
        //必填-充值流水号
        $request->setOutId("yourOutId");


        //hint 此处可能会抛出异常，注意catch
        $response = static::getAcsClient()->getAcsResponse($request);

        return $response;
    }

    /**
     * 流量按套餐发放
     *
     * @return stdClass
     * @throws ClientException
     */
    public static function chargeByOffer() {

        $request = new ChargeByOfferRequest();

        //可选-启用https协议
        //$request->setProtocol("https");

        //必填: 需要充值的手机号
        $request->setPhoneNumber("13000000000");
        //必填: 需要充值的套餐ID，请参阅：https://dycdp.console.aliyun.com/dycdp.htm#/account/price/list
        $request->setOfferId("22020000112089");
        //选填: 充值备注
        $request->setReason("活动充值送流量");
        //必填: 外部扩展字段
        $request->setOutId("yourOutId");


        //hint 此处可能会抛出异常，注意catch
        $response = static::getAcsClient()->getAcsResponse($request);

        return $response;
    }

    /**
     * 流量充值记录查询
     *
     * @return stdClass
     * @throws ClientException
     */
    public static function queryChargeDetail() {

        $request = new QueryChargeDetailRequest();

        //可选-启用https协议
        //$request->setProtocol("https");

        //必填-充值流水号，由调用方在调用充值接口时指定
        $request->setOutId("yourOutId");

        //hint 此处可能会抛出异常，注意catch
        $response = static::getAcsClient()->getAcsResponse($request);

        return $response;
    }

    /**
     * 流量档位查询
     *
     * @return stdClass
     * @throws ClientException
     */
    public static function queryGrades() {

        $request = new QueryGradesRequest();

        //可选-启用https协议
        //$request->setProtocol("https");

        //选填-待充值号码
        $request->setPhoneNumber("4001112222");

        //hint 此处可能会抛出异常，注意catch
        $response = static::getAcsClient()->getAcsResponse($request);

        return $response;
    }
}

// 调用示例：
set_time_limit(0);
header("Content-Type: text/plain; charset=utf-8");

$response = CdpDemo::queryGrades();
echo "流量档位查询(queryGrades)接口返回的结果\n";
print_r($response);

sleep(3);

$response = CdpDemo::charge();
echo "流量发放(charge)接口返回的结果\n";
print_r($response);

sleep(3);

$response = CdpDemo::chargeByOffer();
echo "流量按套餐发放(chargeByOffer)接口返回的结果\n";
print_r($response);

sleep(3);

$response = CdpDemo::queryChargeDetail();
echo "流量充值记录查询(queryChargeDetail)接口返回的结果\n";
print_r($response);